@@ -1,7 +1,10 @@
+/**
+ * \file frame.h
+ */
+
 /*
- * frame.h
- *
  * Copyright (C) 1997 Rasca Gmelch, Berlin
+ * Copyright (C) 2003-07 Karl H. Beckers, Frankfurt
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -10,7 +13,7 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
@@ -18,8 +21,17 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-XRectangle XVC_frame_rectangle;
-int XVC_frame_lock;
+#ifndef __XVC_FRAME_H__
+#define __XVC_FRAME_H__
 
-XRectangle *GetArea (void);
-int IsFrameLocked (void);
+XRectangle *xvc_get_capture_area (void);
+int xvc_is_frame_locked (void);
+void xvc_set_frame_locked (int);
+void xvc_get_window_attributes (Window win, XWindowAttributes * wa);
+
+// the following are implementation dependent and actually implemented
+// in gnome_frame.c
+void xvc_frame_drop_capture_display ();
+Display *xvc_frame_get_capture_display ();
+
+#endif     // __XVC_FRAME_H__
