@@ -1,6 +1,7 @@
+/**
+ * \file xtoxwd.h
+ */
 /*
- * xtoxwd.h
- *
  * Copyright (C) 1997 Rasca Gmelch, Berlin
  *
  * This program is free software; you can redistribute it and/or modify
@@ -10,7 +11,7 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
@@ -18,6 +19,10 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-void XImageToXWD (FILE *fp, XImage *image, Job *job);
-void *XWDcolorTable (XColor *colors, int ncolors);
+#ifndef __X_TO_XWD_H__
+#define __X_TO_XWD_H__
 
+void xvc_xwd_save_frame (FILE * fp, XImage * image);
+void *xvc_xwd_get_color_table (XColor * colors, int ncolors);
+
+#endif     // __X_TO_XWD_H__
